@@ -433,27 +433,32 @@ project_move(project_t * project, const char *new_dir)
 	client_t *client = NULL;
 	char *esc_proj_dir = NULL;
 	char *esc_new_proj_dir = NULL;
-
+	char *esc_new_proj_bak_dir = NULL;
+	DIR *dir = NULL;
+	
 	if (strcmp(new_dir, project->directory) == 0)
 		return;
+	
+	esc_proj_dir = escape_file_name(project->directory);
+	esc_new_proj_dir = escape_file_name(new_dir);
 
 	/* Check to be sure directory is acceptable
 	 * FIXME: thorough enough error checking? */
-	DIR *dir = opendir(new_dir);
+	dir = opendir(esc_new_proj_dir);
 
 	if (dir != NULL) {
 		fprintf(stderr,
-				"Warning: directory %s exists, files may be overwritten.\n",
+				"Can not move project directory to %s - exists\n",
 				new_dir);
-		closedir(dir);
+		return;
 	} else if (dir == NULL && errno == ENOTDIR) {
 		fprintf(stderr,
 				"Can not move project directory to %s - exists but is not a directory\n",
 				new_dir);
 		return;
 	} else if (dir == NULL && errno == ENOENT) {
-		printf("Directory %s does not exist, and will be created.\n",
-			   new_dir);
+		/* This is what we want... */
+		/*printf("Directory %s does not exist, creating.\n", new_dir);*/
 	}
 
 	/* close all the clients' stores */
@@ -464,8 +469,7 @@ project_move(project_t * project, const char *new_dir)
 	}
 
 	/* move the directory */
-	esc_proj_dir = escape_file_name(project->directory);
-	esc_new_proj_dir = escape_file_name(new_dir);
+	
 
 	if (rename(esc_proj_dir, esc_new_proj_dir)) {
 		fprintf(stderr, "Unable to move project directory to %s (%s)",
@@ -754,8 +758,9 @@ project_t *
 project_new_from_xml(server_t * server, xmlDocPtr doc)
 {
 	xmlNodePtr projectnode, xmlnode;
-	xmlChar *content;
-
+	xmlChar *content = NULL;
+	project_t *project = NULL;
+	
 	for (projectnode = doc->children; projectnode;
 		 projectnode = projectnode->next)
 		if (projectnode->type == XML_ELEMENT_NODE
@@ -767,8 +772,6 @@ project_new_from_xml(server_t * server, xmlDocPtr doc)
 		return NULL;
 	}
 
-	project_t *project;
-
 	project = project_new(server);
 
 	for (xmlnode = projectnode->children; xmlnode; xmlnode = xmlnode->next) {
